Mancala Game related definitions
Mancala is a game with many variants. Here we focus on one variant, but we allow different number of bowls.
The code below shows how one would build a standard mancala game.
let game =
GameBuilder::new()
.bowls(6)
.stones(4)
.build();Structs
- Game
- Game is an sequence of Positions.
- Game
Builder - GameBuilder is used to create a Mancala game.
- Position
- Position is a instance of the board.